#ifndef TRACKER_H_
#define TRACKER_H_

//=========================================================================================
//  Define symbolic constants and macros
//=========================================================================================
#define PI 3.1415926535897932384626433832795 
#define AVOG 6.02214179e23 // Avogadro's number
#define PROTON 1.602176487e-19 // elementary positive charge [C]
#define KB 1.3806504e-23 // Boltzmann constant [J/K]

#define ForBoundary(side,axis)  for( axis=0; axis<mg.numberOfDimensions(); axis++ ) \
    for( side=0; side<=1; side++ )
#define ForParticlesAndDims(particle,dim) for (particle=0; particle<NoOfParticles; particle++) \
    for (dim=0; dim<Dim; dim++)
#define ForSims(sim) for (sim=1; sim<=NoOfSims; sim++)
#define ForSimsMPI(sim) for (sim=rank+1; sim<=NoOfSims; sim+=size)
#define ForSteps(step) for (step=0; step<NoOfTimeSteps; step++)
#define ForProdSteps(prodstep) for (prodstep=0; prodstep<NoOfProdSteps; prodstep++)
#define ForParticles(particle) for (particle=0; particle<NoOfParticles; particle++)
#define ForParticlesReverse(particle) for (particle=NoOfParticles-1; particle>=0; particle--)
#define ForParticles2(particle2) for (particle2=0; particle2<NoOfParticles; particle2++)
#define ForDims(dim)  for (dim=0; dim<Dim; dim++)
#define ForGrids(grid) for( grid=0; grid<cg.numberOfComponentGrids(); grid++ ) // loop over component grids 
#define For3I(i1,i2,i3,I1,I2,I3) for( i3=I3.getBase(); i3<=I3.getBound(); i3++ )  for( i2=I2.getBase(); i2<=I2.getBound(); i2++ )  for( i1=I1.getBase(); i1<=I1.getBound(); i1++ )
#define For3I_Interior(i1,i2,i3,I1,I2,I3) for( i3=I3.getBase()+1; i3<I3.getBound(); i3++ )  for( i2=I2.getBase()+1; i2<I2.getBound(); i2++ )  for( i1=I1.getBase()+1; i1<I1.getBound(); i1++ )
#define boundary BCTypes::boundary1+side+2*axis

#define MSRGYR(step)  PPD(row_msrgyr,step)
#define MSEED(step)   PPD(row_mseed,step)
#define STRETCH(step) PPD(row_stretch,step)
#define MSD(step)     PPD(row_msd,step)
#define VAF(step)     PPD(row_vaf,step)
#define COM(dim,step) PPD(row_com+dim,step)
#define VCOM_AVG(dim) PPS(row_vcom_avg+dim)
#define DIFF_MSD      PPS(row_diff_msd)
#define DIFF_VAF      PPS(row_diff_vaf)

//=========================================================================================
//  Global variables
//=========================================================================================
enum labels {inflow2=1, inflow1, outflow1, outflow2, slipWall, noSlipWall, noSlipWall2, noSlipWall3, periodic}; // label boundary conditions (start from 1, since we test if bc > 0)
enum indicesPPD {i_msrgyr, i_mseed, i_stretch, i_msd, i_vaf, i_com}; // indices for dynamic polymer properties matrix
enum indicesPPS {i_diff_msd, i_diff_vaf, i_vcom_avg}; // indices for static polymer properties matrix
CompositeGrid cg;
struct BC // declare structure for boundary conditions (Navier-Stokes)
{
  double p_inflow1; 
  double p_inflow2; 
  double p_outflow1; 
  double p_outflow2; 
  double v_wall;
} BC_NS = {0.,0.,0.,0.,0.};

struct fe // forceEval() data
{
  double 
    f_MS,
    f_H,
    v_EV, 
    Nks, 
    Rs2, 
    vdw_e, 
    vdw_s, 
    exp_EV, 
    f_EV1, 
    f_EV2, 
    lb, 
    f_ES;
};

//=========================================================================================
//  Function prototypes
//=========================================================================================
float ranf(); //prototype random generator routine
float box_muller(float, float); // prototype Box Muller transform routine
int Partition(int low,int high,double arr[]); // prototype QuickSort routines
void Quick_sort(int low,int high,double arr[]);
string StringToLower(string); // prototype string conversion to lowercase routine
double find_minmax(double arr[], int size, int minmax);
int NaN(realCompositeGridFunction & u);
// Polymer processing
void ppInit (doubleArray & PPD, doubleArray & PPS, doubleArray & x0, doubleArray & v0, doubleArray & norm);
void ppUpdate(doubleArray & PPD, doubleArray & PPS, const int prodstep, const doubleArray & position, const doubleArray & velocity, doubleArray & x0, doubleArray & v0, doubleArray & N0, doubleArray & norm, doubleArray & com, doubleArray & vcom, doubleArray & eev);
void ppAverage(doubleArray & PPD, doubleArray & PPS, const double dt_nondim, const doubleArray & norm);
void ppExport(doubleArray & PPD, doubleArray & PPS, const doubleArray & time, aString nameOfHDFFile, double std_diff);

// False-Transients: general
int applyBoundaryConditions( realCompositeGridFunction & u, real t);
int timeSteppingError(const realCompositeGridFunction & u, 
		      realCompositeGridFunction & uold,
		      const double epsilon);
// False-Transients: Navier-Stokes
int applyBoundaryConditionsNS( realCompositeGridFunction & u, real t);
int dudt(realCompositeGridFunction & u, 
	 realCompositeGridFunction & ut, 
	 realCompositeGridFunction & f, 
	 real t);
int euler(real & t, 
	  real dt,
	  realCompositeGridFunction & f,
	  realCompositeGridFunction & u1, 
	  realCompositeGridFunction & u2);
int rungeKutta4(real & t, 
		real dt,
		realCompositeGridFunction & f,
		realCompositeGridFunction & u1, 
		realCompositeGridFunction & u2, 
		realCompositeGridFunction & u3, 
		realCompositeGridFunction & u4);
int adamsBashforth(real & t, 
		   real dt,
		   realCompositeGridFunction & f,
		   realCompositeGridFunction & u, 
		   realCompositeGridFunction & u0,
		   realCompositeGridFunction & u1,
		   realCompositeGridFunction & u2,
		   realCompositeGridFunction & u3);
int 
linearMultiStep(real & t, 
		real dt,
		realCompositeGridFunction & f,
		realCompositeGridFunction & u,  
		realCompositeGridFunction & u0, 
		realCompositeGridFunction & u1, 
		realCompositeGridFunction & u2);
// False-Transients: Poisson-Boltzmann (no 'f')
int applyBoundaryConditionsPB( realCompositeGridFunction & u, real t);
int dudt(realCompositeGridFunction & u, 
	 realCompositeGridFunction & ut, 
	 real t);
int euler(real & t, 
	  real dt,
	  realCompositeGridFunction & u1, 
	  realCompositeGridFunction & u2);
int rungeKutta4(real & t, 
		real dt,
		realCompositeGridFunction & u1, 
		realCompositeGridFunction & u2, 
		realCompositeGridFunction & u3, 
		realCompositeGridFunction & u4);
int adamsBashforth(real & t, 
		   real dt,
		   realCompositeGridFunction & u, 
		   realCompositeGridFunction & u0,
		   realCompositeGridFunction & u1,
		   realCompositeGridFunction & u2,
		   realCompositeGridFunction & u3);
int 
linearMultiStep(real & t, 
		real dt,
		realCompositeGridFunction & u,  
		realCompositeGridFunction & u0, 
		realCompositeGridFunction & u1, 
		realCompositeGridFunction & u2);

extern "C" 
{ 
void dlpoly_initialize_();  
void dlpoly_force_eval_(double*,double*);  
void dlpoly_terminate_();
void zigzag_(int*,float*,float*,float*);
} // prototype with C language linkage

void import_INI(aString,int);
void import_CONFIG(doubleArray & position, doubleArray & velocity, int sim=0);
void rescale_position(doubleArray & position, doubleArray & velocity, doubleArray & position_ini, double Position_rescale, double Velocity_rescale);
void run_Sarw(sarw_data & dat, int sim=0);
void import_grid(const aString);
void export_FIELD_CONTROL(const char*, const char*, int NoOfWallAtoms);
void init_history(const char*, ofstream & history);
void export_history(ofstream & history, const doubleArray & position);
void export_psf(const char*);
void calculate_RDF(const doubleArray & position, doubleArray & RDF, int NoOfShells);
void ann(ANNkd_tree* kdTree, const doubleArray & position, const doubleArray & Dwall, doubleArray & Fwall, realArray & domain_min, realArray & domain_max);
inline void forceEval(const doubleArray & p, doubleArray & f, fe & fed); // make these inline to run faster
inline void rndEval(doubleArray & Random, const doubleArray & Sigma, const double Sigma_reduced);
bool FileExists(string strFilename);
int getNumberOfPoints(CompositeGrid & gc);
void DrawProgressBar(int len, double percent);
void getDomainBounds(realArray & min, realArray & max);
void eval_Quadrupole(realCompositeGridFunction & E, realCompositeGridFunction & Q);
void CM_NS_Build(realCompositeGridFunction & coeff2, int matrix=1, real dt=1);
void CM_NS_ApplyBCs(realCompositeGridFunction & coeff2);
void checkIfInside(const int & step, const doubleArray & position, realArray & min, realArray & max);
void NDist(const float y, const float z, float H, float W, double & D, double & Dx, double & Dy, double & Dz);
int add_walls_to_CONFIG(const char * xyz_file, char * config_file, double Position_rescale);
int shift_position(doubleArray & position, double Position_rescale);
void write_position_to_CONFIG(doubleArray & position, char * config_file);
double variance( const doubleArray & arr, int no );


//=========================================================================================
//  Namespaces for sharing variables among functions
//=========================================================================================
namespace Data_ini {
bool 
  Momentum_transfer,
  False_transients,
  BD,
  P_Oseen,
  Tracers,
  Electrophoretic,
  Dielectrophoretic,
  Molecular_dynamics,
  Electroosmotic, 
  Shear_driven,
  Pressure_driven,
  Electric_field,
  Plot_intermediate,
  Plot_final,
  Electrostatics,
  Export_vmd,
  Com,
  Msrgyr,
  Mseed,
  Stretch,
  Rmsd,
  MsdVaf,
  Cov,
  Rdf;

int
  Vdw,
  Wall,
  Debug,
  SpringLaw,
  LengthScale,
  TimeScale,
  ForceScale,
  OrderOfAccuracy, 
  NoOfParticles,
  NoOfTimeStepsT,
  NoOfTimeSteps,
  NoOfSims,
  N1, 
  N2, 
  N3,
  Mode,
  StepMax, 
  ErrorFreq,
  MTFreq,
  Direction,
  NoOfShells,
  ExportFreq;

long Seed;

float 
  BOND,
  ALPHA,
  THETA;

double 
  ks,
  bk,
  q0,
  vdw_epsilon,
  vdw_sigma,
  dtT, 
  dt,
  dt_d,
  dt_u, 
  dt_v, 
  eps_d,
  eps_u,
  eps_v,
  debye,
  epsilon,
  eta,
  rho,
  temp,
  dep_corr,
  height,
  i_wall, 
  i_wall2,
  a_inflow1, 
  a_inflow2, 
  a_outflow1, 
  a_outflow2,
  charge_p,
  rad_p,
  mass_p,
  lambda,
  shear_rate,
  pressure,
  Aw,
  com_ref_x,
  com_ref_y,
  com_ref_z,
  equil_frac,
  nof,
  friction_corr;

aString 
  nameOfOGFile,
  outputSuffix;
}

namespace Main_misc { 
  // Misc vars
  const int 
    Singleton=1, Null=0, c0=0, c1=1, c2=2, c3=3,
    eq1=0, eq2=1, eq3=2, eq4=3,  // equation numbers
    ic=0, ac=1,    // component numbers (intrinsic, applied el. potentials)
    pc=0, uc=1, vc=2, wc=3;      // component numbers
  int  i1, i2, i3, Dim, Dim0, Dim1, Dim2, d1, d2, d3,
    particle, particle2, dim, step, ft_step, sim,
    origin, delay, n, i, j, k, side, axis, grid;
  double SUM, error_u, error_d, error_v, error_p, C_wall, A_wall, B_wall, delta_w; 
  char buffer[80];
  double L, Tau, u_0, f_0, phi_i_0, phi_a_0, E_0, p_0, zeta_0, mass_0; // Scales for non-dimensionalization
  real spacing, damping;
  real t,
    time0=0,
    time00=0,
    time_START=0,
    time_INI=0,
    time_EIK=0,
    time_PB=0,
    time_W=0,
    time_NS=0,
    time_TD=0,
    time_PD=0,
    time_REALINI=0,
    time_REALFIN=0,
    time_HISTEXPORT=0,
    time_DLPOLY_START=0,
    time_DLPOLY=0,
    time_INTEG=0,
    time_RHSUPDATE=0,
    time_NSUPDATE=0,
    time_MTRANSFER=0, 
    time_PDINI=0,
    time_PPEVAL=0,
    time_PPEXPORT=0,
    time_COM=0,
    time_MSRGYR=0,
    time_MSEED=0,
    time_STRETCH=0,
    time_MSD=0; // declare & initialize timers
  real timeForBoundaryConditions=0.,
    timeForSolveInterpolate=0.,
    timeForDudt=0.;
  Range all; // null range (entire range)
  Range R0(0,0), R1(1,1), R2(2,2), R1D, RDim(0,Dim); // component ranges (R0 also use a dummy dimension)
  Index I1, I2, I3, Ib1, Ib2, Ib3, Ig1, Ig2, Ig3, Ig21, Ig22, Ig23, Ig_1, Ig_2, Ig_3;
  deque< realCompositeGridFunction > Deque; // create a double-ended queue of CGFs
  // Make some shorter names for BCs for readability
  BCTypes::
    BCNames dirichlet     = BCTypes::dirichlet,
    neumann               = BCTypes::neumann,
    normalComponent       = BCTypes::normalComponent,
    extrapolate           = BCTypes::extrapolate,
    generalizedDivergence = BCTypes::generalizedDivergence,
    allBoundaries         = BCTypes::allBoundaries;
}

  namespace Adams_Bashforth {
 double 
   b3=55./24., // b constants
   b2=-59./24., 
   b1=37./24., 
   b0=-3./8.;
  }

 namespace PP {
   double Diff;
   int prodstep, NoOfProdSteps, NoOfEquilSteps;
   int NT0, NorgT, iorg, dorg, Norg;
   int 
     row_msrgyr=0, 
     row_mseed=0, 
     row_stretch=0, 
     row_msd=0,
     row_vaf=0,
     row_com=0,
     row_diff_msd=0,
     row_diff_vaf=0,
     row_vcom_avg=0;
   intArray PPDrows(10), PPSrows(10);
 }


#endif
