#!/bin/bash 
# Run short Tracker simulations to generate dlpoly input files for subsequent independent wall simulations in dlpoly v3.
#

root=`dirname $0`/.. # Tracker's home directory
ini_wall="INI_files/DATA.INI.wall" # Jednrejack, 9-3, 10-4
ini_tracker="DATA.INI"
dlp_dir="Dlpoly_files"

export TRACKER_HOME=$root
cd $root

H_array=( `seq -w 0.3 0.1 1.3` ) # heights

echo "Re-compile Tracker (y/n)? "
read in
if [ "$in" = "y" ]
then
    . Utils/compile.sh
fi

if [ ! -d $dlp_dir ]; then # create dir if it doesn't exist
    mkdir Dlpoly_files
fi

for h in ${H_array[@]} # loop over H
do

    echo "Running for H=$h..."
    cp $ini_wall $ini_tracker # use the same dt and NoOfTimeSteps for all potentials
    
    sed -i -e 's/height.*=.*/height = '$h'e-6/' \
	-e 's/outputSuffix.*/outputSuffix = W_h'$h'w4/' \
	-e 's/NoOfTimeSteps =.*/NoOfTimeSteps = 1/' \
	-e 's/NoOfSims.*=.*/NoOfSims = 1/' \
	-e 's/ExportFreq.*=.*/ExportFreq = 1/' \
	-e 's/Wall.*=.*/Wall = 4/' $ini_tracker \
	&& cp $ini_tracker ${ini_tracker}.h${h}

    ./Tracker_dlp -ini=DATA.INI.h${h} > job.o_h${h}

    if [ ! -d $dlp_dir/h${h} ]; then # create dir if it doesn't exist
	mkdir $dlp_dir/h${h}
    fi

    echo "Copying CONFIG, FIELD, CONTROL into $dlp_dir/h${h}..."
    cp CONFIG FIELD CONTROL $dlp_dir/h${h}

done


