#!/bin/bash 
# Generate ATOMS.XYZ.h$h files and put them in Walls directory

root=`dirname $0`/.. # Tracker's home directory
wall="ATOMS.XYZ"

H_array=( `seq -w 0.3 0.1 1.3` ) # heights
sigma=0.04 # [microns]
rho0=0.8 # [1/sigma^3]
l=15

cd $root

if [ ! -d "Walls" ]; then # create Walls dir if it doesn't exist
    mkdir Walls
fi

for h in ${H_array[@]} # loop over H
do
    echo "Generating ATOMS.XYZ.h$h..."
    rho=$(echo "scale=10; ${rho0}*${h}^3/${sigma}^3" | bc -l) # recompute density
    genwall/genwall -s ${h}e-6 -d $rho -l $l # generate wall atoms
    genwall/xyz2history $wall Walls/${wall}.h${h}.dlpolyhist -r ${h} # convert to .dlpolyhist for VMD
    mv $wall Walls/${wall}.W_h${h}w4 # move to Walls and rename, add outputSuffix (the new name should correspond to the argument of add_walls_to_CONFIG call in Tracker)
done


