################################################################################
#
# Initialize VMD & show the trajectory
#
# Stages:
# 1) Import some params from DATA.INI (and, for trap simulations, from trap.cmd)
# 2) Load the topology (.psf) and trajectory file (.dlpolyhist)
# 3) Load the bounding geometry (.tcl)
#
# Imported params:
#  traps = number of traps in an array (import from Grids/trap.cmd)
#  height = scale factor [microns] (import from DATA.INI)
#  rad_p = particle radius [microns] (import from DATA.INI)
#  root = Tracker's home dir (import from environment variable TRACKER_HOME)
#
################################################################################

############################# INPUT SET BY USER! ###############################
# Set output suffix of VMD files (see DATA.INI for info)
set outputSuffix "W"
# Set the name of the bounding geometry file (see Grids/*.tcl): pipe3D, trap, 
# or separator
set geometry "pipe3D"
################################################################################


### 1)
# Tracker's home
set root "/home/administrator/cvswork/Tracker"
#!!!$env(TRACKER_HOME)
# Tracker's output dir name (change this if not applicable)
set output "Output"
# Import # of traps
#!!!set traps  [exec sh -c  {sed -n "s/\$n[ ]*=[ ]*\([0-9.e+-]*\).*/\1/p" < $TRACKER_HOME/Grids/trap.cmd}]
#!!!# Import height and rad_p, convert [m] to microns
#!!!set height [expr [exec sh -c  {sed -n "s/height[ ]*=[ ]*\([0-9.e+-]*\).*/\1/p" < $TRACKER_HOME/DATA.INI}]*1e6]
#!!!set rad_p  [expr [exec sh -c  {sed -n "s/rad_p[ ]*=[ ]*\([0-9.e+-]*\).*/\1/p" < $TRACKER_HOME/DATA.INI}]*1e6]

set traps  [exec sh -c  {sed -n "s/\$n[ ]*=[ ]*\([0-9.e+-]*\).*/\1/p" < /home/administrator/cvswork/Tracker/Grids/trap.cmd}]
# Import height and rad_p, convert [m] to microns
set height [expr [exec sh -c  {sed -n "s/height[ ]*=[ ]*\([0-9.e+-]*\).*/\1/p" < /home/administrator/cvswork/Tracker/DATA.INI}]*1e6]
set rad_p  [expr [exec sh -c  {sed -n "s/rad_p[ ]*=[ ]*\([0-9.e+-]*\).*/\1/p" < /home/administrator/cvswork/Tracker/DATA.INI}]*1e6]

##...or set these params manually:
#set root /home/administrator/interface
#set traps 4
#set height 3
#set rad_p 0.077

### 2)
# Load topology file (.psf) and trajectory file (.dlpolyhist)
mol load psf $root/$output/CHAIN_$outputSuffix.psf
mol addfile $root/$output/HISTORY_$outputSuffix.dlpolyhist waitfor all
# Set CPK params [sphere scale, bond radius, sphere resolution]
set cpk "CPK 1 0.1 12"
mol modstyle all all $cpk
set sel [atomselect top all]
# In VMD, CPK radius is 4x VDW radius (don't ask my why...)
$sel set radius [expr $rad_p*4]

### 3)
puts "\nLoading $geometry geometry from $root... \nParameters: height=$height microns, bead radius=$rad_p microns\n"

if {$geometry == "trap"} {
source $root/Grids/trap.tcl
trap $traps $height
} elseif {$geometry == "separator"} {
source $root/Grids/separator.tcl
separator $height
} elseif {$geometry == "pipe3D"} {
source $root/Grids/pipe3D.tcl
pipe3D $height
} else {
puts "\nGeometry not supported. Check the geometry variable.\n"
}

