%Visualization script for Tracker's HDF output file
clc, clear all, close all
Nref=11; % reference chain length (should equal NoOfParticles for confinement simulation)

% Import data from runsims.m & define some other variables
runsims;
symbol=['x' 'o']; % plot symbols for FD and HI
marker={'bo' 'kx','r+','c*','ms','bd','kv','r^','c<','m>','bp','kh','r.'}; % other markers
color={'b' 'k','r','c','m','b' 'k','r','c','m','b' 'k','r','c','m','b' 'k','r','c','m','b' 'k','r','c','m'}; % other colors
i_msrgyr=1; i_mseed=2; i_stretch=3, i_msd=4; i_vaf=5; i_com=6; % see enum indices in Tracker.h (dynamic)
i_diff_msd=1; i_diff_vaf=2; i_vcom_avg=3;

% Polymer physics (Rubinstein)
bk=0.09e-6; % effective bond length - see below for calculation
KB=1.3806504e-23; FRICTION=6*pi*eta*rad_p; Diff=KB*temp/FRICTION;
Nks=20; % # Kuhn segments per spring
nu=3/5; % inverse of fractal dimension for an ideal chain
lp=bk/2; % persistence length
Nmax=length(N); w=ceil(sqrt(Nmax)); Hmax=length(H_array); 

for k=1:Nmax
    % results from polymer theory
    R=bk*(N(k)-1)^nu; % size (Ns=N-1)
    Rmax=(N(k)-1)*q0; % contour length
    R20=Rmax*bk - .5*bk*bk*(1-exp(-2*Rmax/bk)); % mean square E-E
    Ee_theory(k)=sqrt(R20) /q0; % end-to-end distance (Rub2.36) [normalized by q0]
    Rgyr_theory(k)=Ee_theory(k)/ sqrt(6); % radius of gyration (Rub2.54, Jen11) [normalized by q0]
    Diff_rouse(k)=Diff/N(k) /Diff; % Rouse diffusivity [normalized by S-E diff.]
    Diff_zimm(k)=0.196*KB*temp/(eta*R) /Diff; % Zimm diffusivity [normalized by S-E diff.]
    tau_relax_rouse(k)=6*pi*eta*rad_p*N(k)*R20/(6*pi^2*KB*temp); % relax. time (use q0 instead of rad_p ?!)
    tau_relax_zimm(k)=0.163*eta*R^3/(KB*temp);
end

% *** 1) RELAXATION ***
if(relaxation)
    
    for k=1:Nmax
        % process HDF
        if HI
            filename=['../Output/DATA_R_', int2str(N(k)), '.HDF']; % use HI data if available...
        else
            filename=['../Output/DATA_R_FD_', int2str(N(k)), '.HDF']; % otherwise use FD data
        end
        [info, NoOfSDS, root, time, Tref, L, Tau, u_0, ppdrows, ppsrows]=import_metadata(filename);        
        for i=1:NoOfSDS % loop over available datasets
            [SDS(i).Name, SDS(i).Data]=import_sds(i,info);
            if isequal(SDS(i).Name, strcat(root,'PPD'))
                % Process DIR_STRETCH
                [estimates, model] = fitcurve(time,SDS(i).Data(ppdrows(i_stretch),:)); % fit with exponential
                [sse, FittedCurve] = model(estimates); % save to FittedCurve for plotting
                tau_relax(k)=estimates(3); % save relaxation time
                figure(1);
                % plot dir_stretch vs time
                if N(k)==Nref; plot(time, SDS(i).Data(ppdrows(i_stretch),:), 'o'); end
                hold on
                % plot fitted curve
                plot(time, FittedCurve, 'r');
                xlabel('Time [s]'); ylabel('Directional stretch normalized by contour length');
                title(['Stretch VS Time'], 'FontWeight', 'bold');
                legend('data', ['fit using A*exp(-t/Tau)+B, annotations: [N, \tau_r (s)]'])
                % annotate with pairs [NoOfBeads, Tau_relax]
                text(0.85, FittedCurve(end)+0.01, ['[', num2str(N(k)), ' , ', num2str(estimates(3),1),']'], 'FontWeight','bold');
            end
        end
    end %for(k)
    
    figure(3);
    semilogy(N,tau_relax,'o', N,tau_relax_zimm,'--r', N,tau_relax_rouse,':b'); % D vs N
    xlabel('N'); ylabel('\tau_r [s]');
    title(['Relaxation time vs chain length'], 'FontWeight', 'bold');
    legend('Simulation (HI)', 'Zimm relaxation time \tau_Z \propto N^{3\nu}', 'Rouse relaxation time \tau_R \propto N^2')
    
end % if relaxation

% *** 2) SCALING ***
if(scaling)
    for fig=10:12 % set figure params
        figure(fig); 
        %set(gca,'YScale', 'log','XScale', 'log','XTick', N, 'XLim', [min(N) max(N)]);
    end
    for model=1:HI+1 % loop over FD and HI models
        for k=1:Nmax % HI
            % process HDF
            if model==1
                filename=['../Output/DATA_S2_FD_', int2str(N(k)), '.HDF']; % otherwise use FD data
                %filename=['../Output/DATA_vulcan.HDF']; % otherwise use FD data                
            elseif model==2
                filename=['../Output/DATA_S_', int2str(N(k)), '.HDF']; % use HI data if available...
            end
            [info, NoOfSDS, root, time, Tref, L, Tau, u_0, ppdrows, ppsrows]=import_metadata(filename);
            % Import datasets into a structure
            for i=1:NoOfSDS % loop over available datasets
                [SDS(i).Name, SDS(i).Data]=import_sds(i,info);                
                if isequal(SDS(i).Name, strcat(root,'PPD'))
                    % MSD -> DIFF_MSD
                    MSD(model,k,:)=SDS(i).Data(ppdrows(i_msd),:);
%                      linfit=polyfit(time,MSD(model,k,:),1);
%                      DIFF(model,k)=.5*linfit(1) / (Diff/L/L*Tau); 
%                      %D = 1/2 * grad(MSD) [normalized, uses mean MSD]
                    % VAF -> DIFF_VAF
                    VAF(model,k,:)=SDS(i).Data(ppdrows(i_vaf),:);
%                     % VCOM_AVG
%                     VCOM_AVG=SDS(i).Data(ppsrows(i_vcom_avg)+0); % x-comp of COM vel. average                    
%                     % VCOM (assume COM contains VCOM => change in
%                     % Tracker.C!)
%                     COMVX=squeeze( SDS(i).Data(ppdrows(i_com)+0,:) ); 
%                     COMVY=squeeze( SDS(i).Data(ppdrows(i_com)+1,:) ); 
%                     COMVZ=squeeze( SDS(i).Data(ppdrows(i_com)+2,:) );
%                     VV=sqrt(COMVX.^2+COMVY.^2+COMVZ.^2); 
                    % Rgyr
                    MSRGYR(model,k)=sum(SDS(i).Data(ppdrows(i_msrgyr),:))/Tref;
                    b_eff_rg(k)=sqrt(6*MSRGYR(model,k)/Nks/(N(k)-1))*q0*1e6; % effective bond length [microns]
                    % E-E
                    MSEED(model,k)=sum(SDS(i).Data(ppdrows(i_mseed),:))/Tref;
                    b_eff_r(k)=sqrt(MSEED(model,k)/Nks/(N(k)-1))*q0*1e6; % effective bond length [microns]
                elseif isequal(SDS(i).Name, strcat(root,'PPS'))                
                    DIFF(model,k)=SDS(i).Data(ppsrows(i_diff_msd));            
                    if model==2
                        DIFF(model,k)=DIFF(model,k)*10; % multiply by 1/friction_corr
                    end                      
                end
            end
        end
        figure(10); hold on;
        hD(model)=loglog(N,DIFF(model,:),symbol(model)); % DIFF vs N
        figure(11); hold on;
        hR(model)=loglog(N,sqrt(MSRGYR(model,:)),symbol(model)); % Rgyr vs N
        figure(12); hold on;
        hE(model)=loglog(N,sqrt(MSEED(model,:)),symbol(model)); % E-E vs N
    end
    
    if exist('b_eff_r')  display(['Effective bond length (from R) [microns] vs N: ', num2str(b_eff_r)]); end
    if exist('b_eff_rg') display(['Effective bond length (from Rg) [microns] vs N: ', num2str(b_eff_rg)]); end
    
    % add theoretical plots
    figure(10); xlabel('N'); ylabel('D/Dm');
    title(['Center of mass diffusion coefficient vs chain length'], 'FontWeight', 'bold');
    hDT=semilogy(N,Diff_rouse,':b'); % D vs N (Rouse)
    legend([hDT hD],'Rouse diffusivity D_R \propto N^{-1}', 'Simulation (FD)', 'Simulation (HI)');
    hDT2=semilogy(N,Diff_zimm,'--r'); % D vs N (Zimm)
    legend([hDT hDT2 hD],'Rouse diffusivity D_R \propto N^{-1}','Zimm diffusivity D_Z \propto N^{-3/5}','Simulation (FD)', 'Simulation (HI)');
    
    figure(11); xlabel('N'); ylabel('R_{g}/q_0');
    title(['Radius of gyration vs chain length'], 'FontWeight', 'bold');
    hRT=semilogy(N,Rgyr_theory,':b'); % Rgyr vs N (theory)
    legend([hRT hR],'Theory, R_{g} \propto \surd N','Simulation (FD)', 'Simulation (HI)')
    
    figure(12); xlabel('N'); ylabel('R_{e}/q_0');
    title(['End-to-end distance vs chain length'], 'FontWeight', 'bold');
    hET=semilogy(N,Ee_theory,':b'); % E-E vs N (theory)
    legend([hET hE],'Theory, R_{e} \propto \surd N','Simulation (FD)', 'Simulation (HI)')
    
    %     if ismember(Nref, N)
    %         % Pe -> grad(p) (Usta & Ladd)
    %         if N(k)==Nref
    %             D=DIFF*Diff; % bulk value for diffusivity [m2/s]
    %             Rg=sqrt(MSRGYR(model,k))*q0; % bulk value for radius of gyration [m2]
    %         end
    %         Pe=10;
    %         grad_p=Pe*4*eta*D/(Rg*Rg*Hpdf*1e-6); % Hpdf [microns]
    %         display(['Grad(p) required for Pe=', num2str(Pe), ': ', num2str(grad_p), ' Pa'])
    %     end
    
end % end if(scaling)

% *** 3) CONFINEMENT ***
if(confinement)
    for k=1:Hmax % HI
        % process HDF
        if HI
            filename=['../Output/DATA_C_', int2str(H_array(k)), '.HDF']; % use HI data if available...
        else
            filename=['../Output/DATA_C_FD_', sprintf('%1.1f', H_array(k)), '.HDF']; % otherwise use FD data
        end
        [info, NoOfSDS, root, time, Tref, L, Tau, u_0, ppdrows, ppsrows]=import_metadata(filename);
        % Import datasets into a structure
        for i=1:NoOfSDS % loop over available datasets
            [SDS(i).Name, SDS(i).Data]=import_sds(i,info);            
            if isequal(SDS(i).Name, strcat(root,'PPD'))
                if H_array(k)==1.0 %Hpdf % P(y) vs y
                    COM_y=squeeze( SDS(i).Data(ppdrows(i_com)+1,:) ); % y-coord (2nd) of Center Of Mass position
                    [bandwidth,density,xmesh]=kde(COM_y,2^6,0.35, 0.65);
                    %hist(COM_y,100);
                end            
                % Process DIR_STRETCH
                [estimates, model] = fitcurve(time,SDS(i).Data(ppdrows(i_stretch),:)); % fit with exponential
                [sse, FittedCurve] = model(estimates); % save to FittedCurve for plotting
                tau_relax(k)=estimates(3); % save relaxation time
                figure(1);
                % plot dir_stretch vs time
                %plot(time, SDS(i).Data(ppdrows(i_stretch),:), 'o');
                %hold on
                % plot fitted curve
                plot(time, FittedCurve, color{k}); hold on;
                xlabel('Time [s]'); ylabel('Directional stretch normalized by contour length');
                title(['Stretch VS Time'], 'FontWeight', 'bold');
                legend('data', ['fit using A*exp(-t/Tau)+B, annotations: [N, \tau_r (s)]'])
                % annotate with pairs [NoOfBeads, Tau_relax]
                %text(0.85, FittedCurve(end)+0.01, ['[', num2str(N(k)), ' , ', num2str(estimates(3),1),']'], 'FontWeight','bold');
            elseif isequal(SDS(i).Name, strcat(root,'PPS'))                
                DIFF_C(k)=SDS(i).Data(ppsrows(i_diff_msd));
            end
        end
    end
    figure(21);
    if(scaling)
        Hstar=sqrt(MSRGYR(model,find(N==Nref))) ./ (H_array*1e-6/q0);
        DIFF_C = DIFF_C / DIFF(model,find(N==Nref));  % D vs H (H in microns); if scaling (bulk flow) results available, use them for normalization...
    else
        Hstar=Rgyr_theory(find(N==Nref)) ./ (H_array*1e-6/q0); % ... otherwise normalize by the theoretical values
        DIFF_C = DIFF_C / Diff_rouse(find(N==Nref));
    end
    C1=loglog(Hstar,DIFF_C ,'o');
    hold on
    C2=loglog(Hstar,27e-2*Hstar.^(-2/3),'--r'); % renormalization group scaling ~ (1/H)^(2/3)
    %loglog(Hstar,1-2.104*(3.2*Hstar)+2.09*(3.2*Hstar).^3-0.95*(3.2*Hstar).^5,':b'); % Faxen's expression for sphere in a channel
    xlabel('R_{gyr}/H'); ylabel('D/D_{bulk}');
    title(['Center of mass diffusion coefficient vs 1/H'], 'FontWeight', 'bold');
    %xlim([1e-2 0.2])
    legend([C1 C2],'Simulation (FD)', 'D/D_{bulk} \propto (1/H)^{-2/3}')
        
    figure(22);
    plot(xmesh,density); % KDE estimate of pdf
    xlabel('y [\mum]'); ylabel('P(y)');
    xlim([0.35 0.65])
    title(['Center of mass distribution across y-direction'], 'FontWeight', 'bold');
    %%figure(8); hist(COM_y,50); % histogram estimate of pdf
    
end % end if(confinement)

% *** 4) ENTROPIC TRAP ***
trap=0;
if(trap)
 
    Ntrap2=Ntrap; Vtrap2=Vtrap; % backup Ntrap & Vtrap
    
    % *** I. LOOP OVER V
    %display(['Looping over V, N fixed:']);
    %Vtrap=Vtrap2; Ntrap=11;

    [VCOM_AVG,L,n,v]=import_vcom_avg(Ntrap,Vtrap,i_vcom_avg); % import vcom_avg
    
    Eavg=Vtrap/L; % average el. field strength [V/m]
    Eavg=repmat(Eavg,[n 1]); % replicate matrix
    mu=VCOM_AVG./Eavg; % elphoretic mobility [m2/s/V]
    mu0=mean(max(mu,[],2)); % free space mobility = saturation value of the mobility curve (max along the 2nd dim)
    tau_trap=abs(L./Eavg.*(1./mu-1/mu0)); % trapping time [s]
    Eavg=Eavg*1e-2; % -> {V/cm]
    
    figure(31);  % mu vs Eavg [V/cm]
    for k=1:n % loop over the rows
        mu_plot(k)=plot(Eavg(k,:),mu(k,:),marker{k}); hold on;
    end
    xlabel('E_{avg} [V/cm]'); ylabel('\mu [m^2 s^{-1} V^{-1}]');
    title(['Mobility of \lambda phage DNA versus average electric field strength'], 'FontWeight', 'bold');
    legend(mu_plot,strcat('N=', strread(num2str(Ntrap),'%s')),'Location','SouthEast')
     
    figure(32); % tau vs Eavg [V/cm]
    for k=1:size(Eavg,1) % loop over the rows
        tau_plot(k)=semilogy(1./Eavg(k,:),tau_trap(k,:),marker{k}); hold on;
    end
    xlabel('1/E_{avg} [cm/V]'); ylabel('\tau [s]');
    title(['Trapping time of \lambda phage DNA in an entropic trap'], 'FontWeight', 'bold');
    legend(tau_plot,strcat('N=', strread(num2str(Ntrap),'%s')),'Location','SouthEast')
    
    hold on; % fit tau
    [row,col]=find(tau_trap==0); % remove zero element (mu=mu0)
    Eavg(:,max(col))=[]; tau_trap(:,max(col))=[]; iE=1./Eavg;
    
    del=14; iE(:,del:end)=[]; tau_trap(:,del:end)=[]; % discard all but last (del-1) points (first points are free-flowing anyway)
    c=polyfit(iE,log(tau_trap),1); % fit a line to the logarithm of tau => y=c1*x+c2
    semilogy(iE(1,:),exp(c(2))*exp(c(1).*iE),'r');
    
    figure(31); % fit mu
    hold on;
    Eavg_fit=0:0.01:max(max(Eavg)); % generate denser Eavg vector fot smooth fit
    mufit=mu0 ./ ( 1 + (mu0.*exp(c(2))/(L*1e-2)) .*Eavg_fit .*exp( c(1)./Eavg_fit )); % fit with exponential
    plot(Eavg_fit,mufit);

%     % *** II. LOOP OVER N
%     display(['Looping over N, V fixed:']);
%     clear VCOM_AVG mu mu_plot;    
%     Ntrap=[6 11 16 21 26 31 36 41]; 
%     Vtrap=[0.013 0.014 0.015 0.016 0.017];
%     
%     [VCOM_AVG,L,n,v]=import_vcom_avg(Ntrap,Vtrap,i_vcom_avg);  % import vcom_avg
% 
%     Eavg=Vtrap/L; % average el. field strength [V/m]
%     Eavg=repmat(Eavg,[n 1]); % replicate matrix
%     Ntrap=repmat(Ntrap,[n 1]); % replicate matrix    
%     mu=VCOM_AVG./Eavg; % elphoretic mobility [m2/s/V]
%     Eavg=Eavg*1e-2; % -> {V/cm]
%     
%     figure(33); % plot
% 
%     for k=1:v % loop over the rows
%         mu_plot(k)=plot(Ntrap(1,:),mu(:,k)./mu0,marker{k}); hold on;  % mu vs Eavg [V/cm]      
%     end
%     legend(mu_plot,strcat('E=', strread(num2str(Eavg(1,:),'%10.1f'),'%s'), ' V/cm'),'Location','SouthEast')
%    
% %     % alternative plot for figure(33): with 2 y-axes
% %     [AX,H1,H2]=plotyy(Ntrap(1,:),mu(:,1)'./mu0,Ntrap(2,:),mu(:,2)'./mu0);
% %     set(H1,'Marker','o','Color','k')
% %     set(H2,'Marker','x','Color','b')
% %     set(AX(1),'ycolor','k')
% %     set(AX(2),'ycolor','b')    
% %     set(get(AX(1),'Ylabel'),'String','\mu/\mu_0 for E_1') 
% %     set(get(AX(2),'Ylabel'),'String','\mu/\mu_0 for E_2')     
% %     xlabel('N');
% %     title(['Mobility of \lambda phage DNA vs number of beads'], 'FontWeight', 'bold');       
% %     legend([H1 H2], 'E_1 = 8.3 V/cm', 'E_2 = 25 V/cm')    
% 
%     
%     xlabel('N'); ylabel('\mu/\mu_0');
%     title(['Mobility of \lambda phage DNA vs number of beads'], 'FontWeight', 'bold');  
%     
end

