%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SIMULATION: POLYMER SCALING LAWS, MASTER INI FILE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- CODE RELATED PARAMETERS ---

Debug = 0		% 1 + 2 + 4 (0 = no debugging)

% *** TIME STEP & TOTAL NUMBER OF TIME STEPS, NUMBER OF SIMULATIONS ***
NoOfSims = 30 	  	% number of simulations
% Choice of dt [s]: 1) dt << t_r particle relaxation time, and
% 2) should satisfy stability of the integrator (trial and error: run for different time steps and compare solutions
% TRACERS
dtT = 1e-7		% time step
NoOfTimeStepsT = 2 	% number of time steps (+1)
% COLLOIDS
dt = 1e-5
NoOfTimeSteps = 100000	% Note: NoOfTimeSteps  =  NoOfTimeSteps2 if 'position comparison plot' required

% *** ON/OFF SWITCHES (0=FALSE, 1=TRUE) ***
Momentum_transfer = 0
False_transients = 1 	% use Method of False Transients or coefficient matrices?
BD = 1 		   	% use Brownian dynamics (BD) or Langevin dynamics (LD) for integration?
P_Oseen = 0 		% use preaveraged Oseen tensor when Navier-Stokes not being updated?
MTFreq = 1 		% frequency of Navier-Stokes resolve?
Tracers = 0 		% include dynamics of tracers?
% Turn on/off forces
Molecular_dynamics = 1
Electrophoretic = 0
Dielectrophoretic = 0
Wall = 1
% Turn on/off fields
Electroosmotic = 0	% velocity fields (3 available)
Shear_driven = 0
Pressure_driven = 0
Electric_field = 0	% electric field
% Turn on/off visualization
Plot_intermediate = 0	% plot intermediate results
Plot_final = 0 	    	% plot final results
% Turn on/off specific molecular dynamics firces
Vdw = 1
Electrostatics = 0 	% turn on/off electrostatic forces in MD (if ON, reaction field method used)
% Post-processing
Export_vmd = 1
Com = 1      		% position of center of mass (COM)
Msrgyr = 1 		% mean sqaure radius of gyration
Mseed = 1 		% mean square end-to-end distance
Stretch = 1
MsdVaf = 1   		% mean square displacement & velocity auto-correlation function
Rdf = 0 		% radial distribution function
    
% *** PARAMS FOR FALSE TRANSIENTS ***
% max number of steps, error update freq.
StepMax = 100000 
ErrorFreq = 100 
% time steps  
dt_d = 1e-5		% Eikonal
dt_u = 1e-5		% Poisson-Boltzmann
dt_v = 1e-5 		% Navier-Stokes
% error tolerances 
eps_d = 1e-4	   	% Eikonal
eps_u = 1e-3		% Poisson-Boltzmann
eps_v = 1e-3 		% Navier-Stokes

% *** INPUT & OUTPUT FILES ***

% *** MISC ***
% Set time steps for r-RESPA integrator
N1 = 1
N2 = 1 
N3 = 1
OrderOfAccuracy = 2	% order of accuracy of difference formulas
% Post-processing params
equil_frac = 0.2	% equilibration time as a fraction of total simulation time
nof = 0.01  		% number of time origins fraction (0~min=1, 1~max=NT)
Direction = 0 		% direction for the directional stretch (0~x, 1~y, 2~z)
NoOfShells = 100 	% number of shells for radial distribution function

friction_corr = 1

% --- PHYSICS RELATED PARAMETERS ---

NoOfParticles = 11	% number of particles

% Bond specs
SpringLaw = 2		% spring laws: 1-FENE, 2-Marko-Siggia
ks = 3.73e42 		% FENE stiffness constant [J/m2]
bk = 1e-7 		% Kuhn length [m]
q0 = 2.1e-6 		% maximum spring extensibility [m]
vdw_epsilon = 2.479e2 	% Lennard-Jones, epsilon [10J/mol] (dlpoly units!, b/c used only in dlpoly)
vdw_sigma = 1000 	% Lennard-Jones, sigma [A] (dlpoly units!, b/c used only in dlpoly)

% Particle specs
% Kang: spherical polysterene particle, 5.7microns, density 1050 kg/cm3 => mass 1050*4/3*Pi*rad_p*rad_p*rad_p
% Jendrejack: lambda-phage DNA, assume human DNA mass  =  6.64e-12 g => bead mass = chain mass / noofbeads
charge_p = -40		% particle charge [proton charge] (use 0.5e-/bp [Keyser et al. and also average of other literature sources])
rad_p =  0.077e-6 	% particle radius [m]
mass_p = 3.16e-16  	% particle mass [kg]

% *** PARAMETERS FOR INITIAL CONFORMATION OF THE SYSTEM ***
% Note that 1st bead is always positioned at [0,0,0]
Mode = 2
BOND = 4000
% params specific to 2D ZIG-ZAG
ALPHA = 180 	     	% bond angle [deg]
THETA = 0 	     	% rotation (counterclockwise) angle [deg]
% params specific to SARW
Seed = 2		% seed for the random number generator (>1)

% *** MATERIAL PROPERTIES in standard SI units ***
% Solvent:  deionized water (low ionic concentration)
debye = 1e-6     	% Debye length [m]
epsilon = 6.9e-10     	% solvent electrical permittivity [C/V/m]
eta = 1e-3           	% solvent dynamic viscosity [Pa.s] (commonly denoted as mu)
rho = 998           	% solvent density (water) [kg/m3]
temp = 298           	% temperature [K] (STD)
dep_corr = 1 	     	% heuristic correction factor that accounts for particle finite size in DEP force (set so that magnitude of DEP comparable to other forces)
% Note: for 2-D and 3-D pipes, c~1e12 and c~1, respectively, give magnitude of F_dep on the order of other forces
height = 2.0e-6
% Poisson-Boltzmann BCs
i_wall = -0.08
i_wall2 = -0.08		% zeta potential @ wall (conducting / insulated walls available for e.g. channel and obstacles) [V]
a_inflow1 = 909
a_inflow2 = 800 
a_outflow1 = 30
a_outflow2 = 0		% potentials @ inlets and outlets [V] (set to 0 at non-existent ports)

lambda = .5 		% under-relaxation in Heun predictor-corrector
shear_rate = 1e3 	% shear rate [s^-1] (for shear flow)
pressure = -1e2 	% pressure gradient (for pressure-driven flow)

% For MODE = 1 or 2:
% Specify the desired initial position (x,y,z) of the Center Of Mass of polymer in the geometry
% (make sure it's well within the grid being used (nameOfOGFile))
% For MODE = 0:
% Specify starting point of the random walker
com_ref_x = 7.5
com_ref_y = 0.5
com_ref_z = 0.5

% Choose scales (length, time, velocity)
LengthScale = 1		% 1-height, 2-radius, 3-max spring extensibility, 4-radius of gyration of ideal chain 5-diffusional
TimeScale = 3 		% 1-relaxation, 2-viscous, 3-diffusive
ForceScale = 1		% 1-thermal


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% - All variables of data_ini namespace have to be supplied here, even though not all may be needed by the program
%   (in which case they will be ignored).
% - Integers must not be written in a scientific notation.
% - Some settings may be mutually incompatible. This is user's responsibility.
% - Case insensitive, blanks ignored, use % or ; for comments, use \ for multiple lines.
% - This file will be parsed by an adapted version of iniParser by Nicolas Devillard.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
relaxation=0
scaling=0
confinement=1
trap=0
vaf=0
HI=0

N=[11]
H_array=[0.3 0.4 0.5 0.6 0.7 0.8 0.9 1.0 1.2 1.4 1.6 1.8 2.0]
Hpdf=1.0
pressure=[1733 17330]
Ntrap=[11 21 31]
Vtrap=[0.01 0.05 0.1]
Zeta=[0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1.0]
