#!/bin/bash 
# Investigate pore translocations
#

root=`dirname $0`/.. # Tracker's home directory
ini="INI_files/DATA.INI.transloc"
ini_tracker="DATA.INI"
msub_script="Utils/msub.sh"
out_dir="\/panfs\/storage.local\/chellagroup\/scratch\/Tracker"

export TRACKER_HOME=$root
cd $root
count=1

W_array=( `seq 2 10` ) # no of particles
H_array=( `seq -w 0.02 0.04 0.36` ) # voltage [V]

# W_array=( 2 5 ) # no of particles
# H_array=( 0.1 0.3 ) # voltage [V]

A_array=( 1 ) # N/A

echo "Re-compile Tracker (y/n)? "
read in
if [ "$in" = "y" ]
then
    . Utils/compile.sh
fi

for w in ${W_array[@]} # loop over W
do
    for h in ${H_array[@]} # loop over H
    do
        for a in ${A_array[@]} # loop over A
        do
	echo "Preparing job: W=$w, H=$h, A=$a..."

	cp $ini $ini_tracker

sed -i  -e 's/NoOfParticles.*/NoOfParticles = '$w'/' \
        -e 's/a_inflow1.*/a_inflow1 = '$h'/' \
        -e 's/outputSuffix.*/outputSuffix = PT_h'$h'w'$w'a'$a'/' $ini_tracker \
        && cp $ini_tracker ${ini_tracker}.h${h}w${w}a${a}
	
# hpc cluster
	sed 's/Tracker.*/Tracker -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}

	if [ $count -eq "1" ]; then # iteration = 1
	    JPID=`msub ${msub_script}.h${h}w${w}a${a} | tr -d "\n"`
	else # iteration > 1
	    JPID=`msub -W x=depend:afterany:$JPID ${msub_script}.h${h}w${w}a${a} | tr -d "\n"`
	fi
	echo "Submitted job $JPID."
    
    let count++
done
done
done

