#!/bin/bash 
# Investigate wall interactions
#
# NOTE: For discrete walls, Tracker needs to be compiled with USE_DLPOLY flag on

root=`dirname $0`/.. # Tracker's home directory
ini_wall="INI_files/DATA.INI.wall" # Jednrejack (with different strengths Aw), 9-3, 10-4, WCA
ini_tracker="DATA.INI"
msub_script="Utils/msub.sh"
out_dir="\/panfs\/storage.local\/chellagroup\/scratch\/Tracker"

export TRACKER_HOME=$root
cd $root

count=1
A_array=( 10 ) # wall potential strengths
H_array=( `seq -w 0.3 0.1 1.3` ) # heights
W_array=( 1 ) # wall potentials
#W_array=( 2 3 4 ) # wall potentials

echo "Re-compile Tracker (y/n)? "
read in
if [ "$in" = "y" ]
then
    . Utils/compile.sh
fi

for w in ${W_array[@]} # loop over W
do

    for h in ${H_array[@]} # loop over H
    do
        for a in ${A_array[@]} # loop over Aw
        do
	echo "Preparing job: W=$w, H=$h, Aw=$a..."

	cp $ini_wall $ini_tracker # use the same dt and NoOfTimeSteps for all potentials
	
	sed -i -e 's/height.*=.*/height = '$h'e-6/' \
	    -e 's/Aw =.*/Aw = '$a'/' \
	    -e 's/Momentum_transfer.*/Momentum_transfer = 1/' \
	    -e 's/Export_vmd =.*/Export_vmd = 1/' \
	    -e 's/outputSuffix.*/outputSuffix = W_h'$h'w'$w'a'$a'/' \
	    -e 's/Wall.*=.*/Wall = '$w'/' $ini_tracker \
	    && cp $ini_tracker ${ini_tracker}.h${h}w${w}a${a}
	
# Check whether running locally or on HPC cluster
    if [ `uname -n` == "submit.local" ]
    then
# hpc cluster
	if [ $w -eq "4" ]; then # discrete walls => run with dlpoly support
	    sed 's/Tracker.*/Tracker_dlp -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
	else
	    sed 's/Tracker.*/Tracker -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
	fi
	if [ $count -eq "1" ]; then # iteration = 1
	    JPID=`msub ${msub_script}.h${h}w${w}a${a} | tr -d "\n"`
	else # iteration > 1
	    JPID=`msub -W x=depend:afterok:$JPID ${msub_script}.h${h}w${w}a${a} | tr -d "\n"`
	fi
	echo "Submitted job $JPID."
    else
# local desktop
	echo "Running job..."
	if [ $w -eq "4" ]; then # discrete walls => run with dlpoly support
	    ./Tracker_dlp -ini=DATA.INI.h${h}w${w}a${a} > job.h${h}w${w}a${a}
	else
	    ./Tracker -ini=DATA.INI.h${h}w${w}a${a} > job.h${h}w${w}a${a}
	fi
    fi
    
    let count++
    done
done
done

