#!/bin/bash 
# Investigate wall interactions, HI
#
# NOTE: For discrete walls, Tracker needs to be compiled with USE_DLPOLY flag on

root=`dirname $0`/.. # Tracker's home directory
ini_wall="INI_files/DATA.INI.wall" # Jednrejack, 9-3, 10-4, WCA
ini_tracker="DATA.INI"
msub_script="Utils/msub.sh"
out_dir="\/panfs\/storage.local\/chellagroup\/scratch\/Tracker"

export TRACKER_HOME=$root
cd $root

count=1
#A_array=( 0.04 1e-3 1e-4 1e-5 1e-6 1e-7 ) # step max / CoeffMat vs FT
A_array=( 0.04 ) # step max / CoeffMat vs FT
#A_array=( 5 10 15 20 25 30 35 40 45 50 60 70 80 90 100 125 150 175 200 300 400 500 ) # step max / CoeffMat vs FT
#H_array=( 0.1 0.15 0.2 0.25 `seq -w 0.3 0.1 1.0` ) # heights
#H_array=( 2.0 3.0 4.0 5.0 6.0 7.0 8.0 9.0 10.0 ) # heights
#H_array=( 0.1 0.15 0.2 0.25 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1.0 2.0 5.0 8.0 10.0 ) # heights
H_array=( 0.1  0.5 1.0 ) # heights
W_array=( 0 ) # wall potentials / momentum transfer / Diffusivities

echo "Re-compile Tracker (y/n)? "
read in
if [ "$in" = "y" ]
then
    . Utils/compile.sh
fi

for w in ${W_array[@]} # loop over W
do

    for h in ${H_array[@]} # loop over H
    do
        for a in ${A_array[@]} # loop over A
        do
	echo "Preparing job: W=$w, H=$h, A=$a..."

	cp $ini_wall $ini_tracker # use the same dt and NoOfTimeSteps for all potentials

#	fric_corr=$(echo "scale=10; (9.162862e-02-2.191185e-07*1/${h})^(-1)" | bc -l)

#	if [ $w -eq "0" ]; then # discrete walls => run with dlpoly support
	sed -i -e 's/height.*=.*/height = '$h'e-6/' \
	    -e 's/dt =.*/dt = '$a'/' \
	    -e 's/outputSuffix.*/outputSuffix = W_h'$h'w'$w'a'$a'/' $ini_tracker \
	    && cp $ini_tracker ${ini_tracker}.h${h}w${w}a${a}
# 	else
# 	sed -i -e 's/height.*=.*/height = '$h'e-6/' \
# 	    -e 's/False_transients =.*/False_transients = '$a'/' \
# 	    -e 's/outputSuffix.*/outputSuffix = W_h'$h'w'$w'a'$a'/' \
# 	    -e 's/friction_corr =.*/friction_corr = 8.0/' \
# 	    -e 's/Momentum_transfer.*=.*/Momentum_transfer = '$w'/' $ini_tracker \
# 	    && cp $ini_tracker ${ini_tracker}.h${h}w${w}a${a}
# 	fi
	
# Check whether running locally or on HPC cluster
    if [ `uname -n` == "submit.local" ]
    then
# hpc cluster
# 	if [ $w -eq "1" ]; then 
# 	    sed 's/Tracker.*/Tracker_D2D01 -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
# 	elif [ $w -eq "2" ]; then
# 	    sed 's/Tracker.*/Tracker_D2D12 -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
# 	elif [ $w -eq "3" ]; then
# 	    sed 's/Tracker.*/Tracker_D2D02 -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
# 	elif [ $w -eq "4" ]; then
# 	    sed 's/Tracker.*/Tracker_D1D1 -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
# 	else # 3D
# 	    sed 's/Tracker.*/Tracker_D3D -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}
# 	fi
	    sed 's/Tracker.*/Tracker_D2D02 -ini=DATA.INI.h'$h'w'$w'a'$a' > '$out_dir'\/job.h'$h'w'$w'a'$a'/' < $msub_script > ${msub_script}.h${h}w${w}a${a}

	if [ $count -eq "1" ]; then # iteration = 1
	    JPID=`msub ${msub_script}.h${h}w${w}a${a} | tr -d "\n"`
	else # iteration > 1
	    JPID=`msub -W x=depend:afterany:$JPID ${msub_script}.h${h}w${w}a${a} | tr -d "\n"`
	fi
	echo "Submitted job $JPID."
    else
# local desktop
	echo "Running job..."
	if [ $w -eq "4" ]; then # discrete walls => run with dlpoly support
	    ./Tracker_dlp -ini=DATA.INI.h${h}w${w}a${a} > job.h${h}w${w}a${a}
	else
	    ./Tracker -ini=DATA.INI.h${h}w${w}a${a} > job.h${h}w${w}a${a}
	fi
    fi
    
    let count++
    done
done
done

